@@ -3,7 +3,7 @@ import os
 import csv
 import shutil
 import tarfile
-import urllib.request, urllib.error, urllib.parse
+import urllib2 as urllib
 import datetime
 import json
 from os import makedirs, path
@@ -127,22 +127,24 @@ class PdbFile(ProteinFile):
         except OSError as e:
             pass
         try:
-            response = urllib.request.urlopen('https://files.rcsb.org/view/' + self.pdbcode.upper() + '.pdb')
+            response = urllib.urlopen('https://files.rcsb.org/view/' + self.pdbcode.upper() + '.pdb')
             html = response.read().decode("UTF-8")
             with open(self.out_file, 'w') as myfile:
                 myfile.write(html)
             if self.chain is not None:
                 self.filter_by_chain()
-        except urllib.error.HTTPError as e:
+        except urllib.HTTPError as e:
             print(self.pdbcode + " " + self.chain + " ...trying to download from PDB Bundle")
-            response = urllib.request.urlopen('https://files.rcsb.org/pub/pdb/compatible/pdb_bundle/' + self.pdbcode.lower()[1:3] + '/' + self.pdbcode.lower() + '/' + self.pdbcode.lower() + '-pdb-bundle.tar.gz')
+            response = urllib.urlopen('https://files.rcsb.org/pub/pdb/compatible/pdb_bundle/' + self.pdbcode.lower()[
+                                                                                                1:3] + '/' + self.pdbcode.lower() + '/' + self.pdbcode.lower() + '-pdb-bundle.tar.gz')
             tar = tarfile.open(fileobj=response, mode="r|gz")
             tar.extractall(self.dir)
             tar.close()
-            mapFile, mapChain = self.parsePdbBundleChainIdFile(self.dir + '/' + self.pdbcode.lower() + '-chain-id-mapping.txt')
+            mapFile, mapChain = self.parsePdbBundleChainIdFile(
+                self.dir + '/' + self.pdbcode.lower() + '-chain-id-mapping.txt')
             newChain = mapChain.get(self.chain)
             pdbBundleFile = self.dir + '/' + mapFile.get(self.chain)
-            if newChain!=self.chain:
+            if newChain != self.chain:
                 self.parsePdbAndTranslateChain(pdbBundleFile, self.chain, newChain)
             else:
                 shutil.move(self.dir + '/' + mapFile.get(self.chain), self.out_file)
@@ -159,7 +161,7 @@ class PdbFile(ProteinFile):
 
     @staticmethod
     def parsePdbBundleChainIdFile(chainFile):
-        with open(chainFile, encoding='utf-8') as fp:
+        with open(chainFile) as fp:
             line = fp.readline()
             cnt = 1
             files = []
@@ -169,34 +171,34 @@ class PdbFile(ProteinFile):
             while line:
                 line = line.strip().rstrip()
                 cnt += 1
-                if line.find('pdb-bundle')>=0:
+                if line.find('pdb-bundle') >= 0:
                     actualFile = line[:-1]
                     files.append(actualFile)
                     line = fp.readline()
                     continue
-                elif actualFile!='' and line!='':
+                elif actualFile != '' and line != '':
                     mapping = line.split()
                     key = mapping[1].strip()
                     val = mapping[0].strip()
-                    mapChain[key]=val
+                    mapChain[key] = val
                     mapFile[key] = actualFile
                 line = fp.readline()
             return mapFile, mapChain
 
     # Remapping chain for PDB bundles with many subchains
     def parsePdbAndTranslateChain(self, pdbFileIn, chain, newChain):
-        #print chain + '->' + newChain
+        # print chain + '->' + newChain
         self.out_file = self.out_file.replace(".pdb", "_" + self.chain + ".pdb")
-        with open(pdbFileIn, "r", encoding='utf-8') as infile, open(self.out_file, "w", encoding='utf-8') as outfile:
+        with open(pdbFileIn, "r") as infile, open(self.out_file, "w") as outfile:
             reader = csv.reader(infile)
             for i, line in enumerate(reader):
-                if line[0].find('ATOM')==0 or line[0].find('HETATM')==0:
+                if line[0].find('ATOM') == 0 or line[0].find('HETATM') == 0:
                     newLine = list(line[0])
-                    if newLine[21]==newChain:
+                    if newLine[21] == newChain:
                         if len(chain) > 2:
                             newLine += chain
                             newLine[21] = "%"
-                        elif len(chain)>1:
+                        elif len(chain) > 1:
                             newLine[20] = chain[0]
                             newLine[21] = chain[1]
                         else:
@@ -231,7 +233,7 @@ class MMCIFfile(ProteinFile):
             makedirs(self.dir)
         except OSError as e:
             pass
-        response = urllib.request.urlopen('http://www.ebi.ac.uk/pdbe/entry-files/download/' + self.pdbcode + '.cif')
+        response = urllib.urlopen('http://www.ebi.ac.uk/pdbe/entry-files/download/' + self.pdbcode + '.cif')
         html = response.read().decode("UTF-8")
         with open(self.cif_file, 'w') as myfile:
             myfile.write(html)
@@ -313,17 +315,23 @@ class PDBeSolrSearch:
 
     def exec_query(self, field_list, query_details):
         try:
-            query = { "rows": UNLIMITED_ROWS, "fl": field_list, "q": self.join_with_AND(query_details)}
+            query = {"rows": UNLIMITED_ROWS, "fl": field_list, "q": self.join_with_AND(query_details)}
             response = self.solr.search(**query)
             documents = response.documents
             if DEBUG:
-                logging.getLogger().debug("Found %d matching entities in %d entries." % (len(documents), len({rd["pdb_id"] for rd in documents})))
+                logging.getLogger().debug("Found %d matching entities in %d entries." % (
+                len(documents), len({rd["pdb_id"] for rd in documents})))
             return documents
         except Exception as e:
-            raise SearchException('%s: error getting query response from: %s for: %s\n %s' % (self.__class__.__name__ , PDBE_SOLR_URL, str(query), str(e)))
+            raise SearchException('%s: error getting query response from: %s for: %s\n %s' % (
+            self.__class__.__name__, PDBE_SOLR_URL, str(query), str(e)))
 
     def get(self):
         return self.results
+        # res_decoded = []
+        # for res in self.results:
+        #     res_decoded.append(str(res))
+        # return res_decoded
 
 
 class IdenticalChains(PDBeSolrSearch):
@@ -337,16 +345,20 @@ class IdenticalChains(PDBeSolrSearch):
        ==========
        pdbcode: string - PDB ID
     '''
+
     def __init__(self, pdbcode, chain):
-        super().__init__()
+        PDBeSolrSearch.__init__(self)
 
         self.results = []
         documents = self.exec_query("pdb_id,entity_id,chain_id,assembly_composition", [('pdb_id', pdbcode)])
 
         for i in range(len(documents)):
             chain_id = documents[i]['chain_id']
-            if chain in chain_id:
-                self.results = sorted(chain_id)
+            if chain in sorted(chain_id):
+                chains_to_add = []
+                for ch in chain_id:
+                    chains_to_add.append(str(ch))
+                self.results = sorted(chains_to_add)
                 break
 
 
@@ -364,8 +376,9 @@ class SimilarChains(PDBeSolrSearch):
        seq: string - sequence to compare against - instead od pdbcode and chain
        identity: int - (percentage) of sequence identity
     '''
+
     def __init__(self, pdb=None, chain='A', seq=None, identity=40):
-        super().__init__()
+        PDBeSolrSearch.__init__(self)
         self.chain = chain
         self.pdb = pdb.lower() if pdb else None
         self.identity = float(identity / 100)
@@ -376,7 +389,7 @@ class SimilarChains(PDBeSolrSearch):
             self.seq = seq if seq else self.get_seq()
             self.get_similar()
             self.translate_enity_ids_to_chains()
-        except (urllib.error.URLError, HTTPError, SequenceException) as he:
+        except (urllib.URLError, HTTPError, SequenceException) as he:
             raise SearchException('Problem looking for similar chains to: ' + pdb + ' ' + chain + ': ' + str(he))
 
     def get_seq(self):
@@ -416,7 +429,7 @@ class SimilarChains(PDBeSolrSearch):
   }
 }               
         """ % (self.identity, self.seq)
-        url = "https://search.rcsb.org/rcsbsearch/v1/query?json={0}".format(urllib.parse.quote(query))
+        url = "https://search.rcsb.org/rcsbsearch/v1/query?json={0}".format(urllib.quote(query))
         try:
             response = requests.get(url)
             if response.status_code == 204 and response.text == '':
@@ -428,7 +441,8 @@ class SimilarChains(PDBeSolrSearch):
                 for el in result['result_set']:
                     self.identifiers.append(el['identifier'])
         except Exception as er:
-            raise SearchException('SimilarChains: Error in response from RCSB search for: %s, %s URL:\n%s\n%s' % (self.pdb, self.chain, urllib.parse.unquote(url), str(er)))
+            raise SearchException('SimilarChains: Error in response from RCSB search for: %s, %s URL:\n%s\n%s' % (
+            self.pdb, self.chain, urllib.unquote(url), str(er)))
 
     def translate_enity_ids_to_chains(self):
         if not self.identifiers:
@@ -436,11 +450,12 @@ class SimilarChains(PDBeSolrSearch):
         ident_list = self.identifiers[0]
         for entr_ent in self.identifiers[1:]:
             ident_list += ' OR ' + entr_ent.lower()
-        documents = self.exec_query("pdb_id,entity_id,chain_id,assembly_composition", [('entry_entity', '(' + ident_list + ')')])
+        documents = self.exec_query("pdb_id,entity_id,chain_id,assembly_composition",
+                                    [('entry_entity', '(' + ident_list + ')')])
         for i in range(len(documents)):
             pid = documents[i]['pdb_id']
             chain_id = documents[i]['chain_id']
-            self.results.append((pid.upper(), sorted(chain_id)[0]))
+            self.results.append((str(pid.upper()), str(sorted(chain_id)[0])))
 
     def get(self):
         return sorted(self.results)
@@ -460,8 +475,9 @@ class ReleasedPDBs(PDBeSolrSearch):
           to_date: datetime or string in format YYYY-MM-DD
           uniq_chains: if True return a list of tuples containing (PDBCode, Chain), else return just PDBCodes.
        '''
+
     def __init__(self, from_date, to_date='', uniq_chains=True, only_prot=True, only_rna=False):
-        super().__init__()
+        PDBeSolrSearch.__init__(self)
         if type(from_date) is datetime.date:
             from_date = from_date.strftime("%Y-%m-%d")
         if to_date == '':
@@ -486,7 +502,7 @@ class ReleasedPDBs(PDBeSolrSearch):
             pid = documents[i]['pdb_id']
             chain_id = documents[i]['chain_id']
             if uniq_chains:
-                self.results.append((pid, sorted(chain_id)[0]))
+                self.results.append((str(pid), str(sorted(chain_id)[0])))
             else:
                 if pid not in self.results:
                     self.results.append(pid)
@@ -504,8 +520,9 @@ class UniqueChains(PDBeSolrSearch):
        ==========
        pdbcode: string - PDB ID
     '''
+
     def __init__(self, pdbcode, only_prot=True, only_rna=False):
-        super().__init__()
+        PDBeSolrSearch.__init__(self)
 
         if only_rna:
             molecule_type = 'RNA'
@@ -521,4 +538,4 @@ class UniqueChains(PDBeSolrSearch):
                                     ])
         for i in range(len(documents)):
             chain_id = documents[i]['chain_id']
-            self.results.append(sorted(chain_id)[0])
+            self.results.append(str(sorted(chain_id)[0]))
